@@ -158,15 +158,35 @@ void game::init_recipes()
   COMP(itm_spaghetti_raw, 1, NULL);
   COMP(itm_water, 1, itm_water_dirty, 1, NULL);
 
+ RECIPE(itm_cooked_dinner, CC_FOOD, sk_cooking, sk_null, 0, 5000);
+  TOOL(itm_hotplate, 3, NULL);
+  COMP(itm_frozen_dinner, 1, NULL);
+
  RECIPE(itm_macaroni_cooked, CC_FOOD, sk_cooking, sk_null, 1, 10000);
   TOOL(itm_hotplate, 4, NULL);
   TOOL(itm_pot, -1, NULL);
   COMP(itm_macaroni_raw, 1, NULL);
   COMP(itm_water, 1, itm_water_dirty, 1, NULL);
 
+ RECIPE(itm_potato_baked, CC_FOOD, sk_cooking, sk_null, 1, 15000);
+  TOOL(itm_hotplate, 3, NULL);
+  TOOL(itm_pan, -1, itm_pot, -1, NULL);
+  COMP(itm_potato_raw, 1, NULL);
+
+ RECIPE(itm_oj, CC_FOOD, sk_cooking, sk_null, 1, 5000);
+  TOOL(itm_rock, -1, NULL);
+  COMP(itm_bottle_plastic, 1, NULL);
+  COMP(itm_orange, 2, NULL);
+  COMP(itm_water, 1, itm_water_dirty, 1, NULL);
+
+ RECIPE(itm_apple_cider, CC_FOOD, sk_cooking, sk_null, 2, 7000);
+  TOOL(itm_rock, -1, NULL);
+  COMP(itm_bottle_plastic, 1, NULL);
+  COMP(itm_apple, 3, NULL);
+ 
  RECIPE(itm_jerky, CC_FOOD, sk_cooking, sk_null, 2, 30000);
   TOOL(itm_hotplate, 10, NULL);
-  COMP(itm_salt_water, 1, NULL);
+  COMP(itm_salt_water, 1, itm_salt, 4, NULL);
   COMP(itm_meat, 1, NULL);
 
  RECIPE(itm_V8, CC_FOOD, sk_cooking, sk_null, 2, 5000);
@@ -175,6 +195,43 @@ void game::init_recipes()
   COMP(itm_broccoli, 1, NULL);
   COMP(itm_zucchini, 1, NULL);
 
+ RECIPE(itm_broth, CC_FOOD, sk_cooking, sk_null, 2, 10000);
+  TOOL(itm_hotplate, 5, NULL);
+  TOOL(itm_pot, -1, NULL);
+  COMP(itm_water, 1, itm_water_dirty, 1, NULL);
+  COMP(itm_broccoli, 1, itm_zucchini, 1, itm_veggy, 1, NULL);
+  COMP(itm_can_food, 1, NULL);
+
+ RECIPE(itm_soup, CC_FOOD, sk_cooking, sk_null, 3, 10000);
+  TOOL(itm_hotplate, 5, NULL);
+  TOOL(itm_pot, -1, NULL);
+  COMP(itm_broth, 2, NULL);
+  COMP(itm_macaroni_raw, 1, itm_potato_raw, 1, NULL);
+  COMP(itm_tomato, 2, itm_broccoli, 2, itm_zucchini, 2, itm_veggy, 2, NULL);
+  COMP(itm_can_food, 1, NULL);
+
+ RECIPE(itm_bread, CC_FOOD, sk_cooking, sk_null, 3, 20000);
+  TOOL(itm_hotplate, 8, NULL);
+  TOOL(itm_pot, -1, NULL);
+  COMP(itm_flour, 3, NULL);
+  COMP(itm_water, 2, itm_water_dirty, 2, NULL);
+
+ RECIPE(itm_pie, CC_FOOD, sk_cooking, sk_null, 4, 25000);
+  TOOL(itm_hotplate, 6, NULL);
+  TOOL(itm_pan, -1, NULL);
+  COMP(itm_flour, 2, NULL);
+  COMP(itm_strawberries, 2, itm_apple, 2, itm_blueberries, 2, NULL);
+  COMP(itm_sugar, 2, NULL);
+  COMP(itm_water, 1, itm_water_dirty, 1, NULL);
+
+ RECIPE(itm_pizza, CC_FOOD, sk_cooking, sk_null, 4, 20000);
+  TOOL(itm_hotplate, 8, NULL);
+  TOOL(itm_pan, -1, NULL);
+  COMP(itm_flour, 2, NULL);
+  COMP(itm_veggy, 1, itm_tomato, 2, itm_broccoli, 1, NULL);
+  COMP(itm_sauce_pesto, 1, itm_sauce_red, 1, NULL);
+  COMP(itm_water, 1, itm_water_dirty, 1, NULL);
+
  RECIPE(itm_meth, CC_FOOD, sk_cooking, sk_null, 4, 20000);
   TOOL(itm_hotplate, 15, NULL);
   TOOL(itm_bottle_glass, -1, itm_hose, -1, NULL);
@@ -189,7 +246,7 @@ void game::init_recipes()
  RECIPE(itm_heroin, CC_FOOD, sk_cooking, sk_null, 6, 2000);
   TOOL(itm_hotplate, 3, itm_lighter, 25, NULL);
   TOOL(itm_pan, -1, itm_pot, -1, NULL);
-  COMP(itm_salt_water, 1, NULL);
+  COMP(itm_salt_water, 1, itm_salt, 4, NULL);
   COMP(itm_oxycodone, 40, NULL);
 
  RECIPE(itm_mutagen, CC_FOOD, sk_cooking, sk_firstaid, 8, 10000);
@@ -388,6 +445,8 @@ void game::init_recipes()
   COMP(itm_hose, 1, NULL);
 
  RECIPE(itm_glasses_safety, CC_ARMOR, sk_tailor, sk_null, 1, 8000);
+  TOOL(itm_scissors, -1, itm_xacto, -1, itm_knife_steak, -1,
+       itm_knife_combat, -1, NULL);
   COMP(itm_string_36, 1, itm_string_6, 2, NULL);
   COMP(itm_bottle_plastic, 1, NULL);
 
@@ -418,7 +477,7 @@ void game::init_recipes()
  RECIPE(itm_superglue, CC_MISC, sk_cooking, sk_null, 2, 12000);
   TOOL(itm_hotplate, 5, NULL);
   COMP(itm_water, 1, itm_water_dirty, 1, NULL);
-  COMP(itm_milk, 2, itm_bleach, 1, itm_ant_egg, 1, NULL);
+  COMP(itm_bleach, 1, itm_ant_egg, 1, NULL);
 
  RECIPE(itm_2x4, CC_MISC, sk_null, sk_null, 0, 8000);
   TOOL(itm_saw, -1, NULL);
