@@ -30,7 +30,7 @@ b: Movement\n\
 c: Hunger, Thirst, and Sleep\n\
 d: Pain and Stimulants\n\
 e: Addiction\n\
-f: Morale\n\
+f: Morale and XP\n\
 g: Radioactivity and Mutation\n\
 h: Bionics\n\
 i: Crafting\n\
@@ -181,7 +181,20 @@ Low morale will make you sluggish and unmotivated.  It will also reduce your\n\
 stats, particularly intelligence.  If your morale drops very low, you may\n\
 even commit suicide.  Very high morale fills you with gusto and energy, and\n\
 you will find yourself moving faster.  At extremely high levels, you will\n\
-receive stat bonuses.");
+receive stat bonuses.\n\
+\n\
+Press any key for more...");
+   getch();
+   erase();
+   mvprintz(0, 0, c_white, "\
+Morale is also responsible for filling your XP pool.  This XP pool is used\n\
+for improving your skills; as you use your skills, points are taken from the\n\
+XP pool and placed into the skill used.  If your XP pool is empty, your\n\
+skills cannot be improved except through the use of books.\n\
+\n\
+Your XP pool will not fill unless your morale is at least 0.  A morale level\n\
+between 0 and 100 gives the percentage chance for your XP to increase by 1\n\
+each turn.  Above 100, you get 1 XP point each turn for every 100 morale.");
    getch();
    break;
 
@@ -387,20 +400,20 @@ $ - Lie down to sleep                        ^      - Long wait\n\
 ! - Toggle Run Mode");
    mvprintz(7, 0, c_white, "ITEMS:");
    mvprintz(8, 0, c_ltgray, "\
-i - View Inventory                           d - Drop item\n\
+i - View Inventory                           d,D - Drop item (with direction)\n\
 w - Wield item                               t - Throw item\n\
 W - Wear item                                T - Take off item\n\
 a - Activate tool                            E - Eat comestible\n\
 r - Reload wielded gun or tool               U - Unload wielded gun or tool\n\
 f - Fire gun                                 F - Burst-fire gun\n\
 p - Power up / List bionics                  R - Read book\n\
-& - Craft items                              B - Butcher a corpse");
+& - Craft items                              B - Butcher a corpse\n\
+= - Reassign inventory letter");
    mvprintz(16, 0, c_white, "INFORMATION:");
    mvprintz(17, 0, c_ltgray, "\
 @ - View character status                    : or m - Open world map\n\
-# - List Factions                            ; or x - Look around\n\
-C - Chat with NPC                            ?      - Help page\n\
-%%%% - View morale");
+%%%% - View morale                              ; or x - Look around\n\
+C - Chat with NPC                            ?      - Help page");
    mvprintz(21, 0, c_white, "META:");
    mvprintz(22, 0, c_ltgray, "\
 S - Save game                                Q - Quit w/o saving");
