@@ -21,8 +21,15 @@ int main(int argc, char *argv[])
  curs_set(0);
 
  rand();
- game g;
- while (!g.do_turn());
+ bool quit_game = false;
+ game *g;
+ do {
+  g = new game();
+  while (!g->do_turn());
+  if (g->game_quit())
+   quit_game = true;
+  delete g;
+ } while (!quit_game);
  erase();
  endwin();
  system("clear");
