@@ -57,7 +57,6 @@ ter_id& map::ter(int x, int y)
  return grid[nonant].ter[x][y];
 }
 
-
 std::string map::tername(int x, int y)
 {
  return terlist[ter(x, y)].name;
@@ -117,7 +116,33 @@ bool map::is_outside(int x, int y)
          ter(x - 1, y    ) != t_floor && ter(x - 1, y + 1) != t_floor &&
          ter(x    , y - 1) != t_floor && ter(x    , y    ) != t_floor &&
          ter(x    , y + 1) != t_floor && ter(x + 1, y - 1) != t_floor &&
-         ter(x + 1, y    ) != t_floor && ter(x + 1, y + 1) != t_floor   );
+         ter(x + 1, y    ) != t_floor && ter(x + 1, y + 1) != t_floor &&
+         ter(x    , y    ) != t_floor_wax &&
+         ter(x - 1, y - 1) != t_floor_wax &&
+         ter(x - 1, y    ) != t_floor_wax &&
+         ter(x - 1, y + 1) != t_floor_wax &&
+         ter(x    , y - 1) != t_floor_wax &&
+         ter(x    , y    ) != t_floor_wax &&
+         ter(x    , y + 1) != t_floor_wax &&
+         ter(x + 1, y - 1) != t_floor_wax &&
+         ter(x + 1, y    ) != t_floor_wax &&
+         ter(x + 1, y + 1) != t_floor_wax   );
+;
+}
+
+point map::random_outdoor_tile()
+{
+ std::vector<point> options;
+ for (int x = 0; x < SEEX * 3; x++) {
+  for (int y = 0; y < SEEX * 3; y++) {
+   if (is_outside(x, y))
+    options.push_back(point(x, y));
+  }
+ }
+ if (options.empty()) // Nowhere is outdoors!
+  return point(-1, -1);
+
+ return options[rng(0, options.size() - 1)];
 }
 
 bool map::bash(int x, int y, int str, std::string &sound)
@@ -138,6 +163,7 @@ bool map::bash(int x, int y, int str, std::string &sound)
  switch (ter(x, y)) {
  case t_door_c:
  case t_door_locked:
+ case t_door_locked_alarm:
   if (str >= rng(0, 40)) {
    sound += "smash!";
    ter(x, y) = t_door_b;
@@ -161,6 +187,7 @@ bool map::bash(int x, int y, int str, std::string &sound)
   }
   break;
  case t_window:
+ case t_window_alarm:
   if (str >= rng(0, 6)) {
    sound += "glass breaking!";
    ter(x, y) = t_window_frame;
@@ -197,7 +224,7 @@ bool map::bash(int x, int y, int str, std::string &sound)
   }
   break;
  case t_paper:
-  if (str >= dice(2, 6)) {
+  if (str >= dice(2, 6) - 2) {
    sound += "rrrrip!";
    ter(x, y) = t_dirt;
    return true;
@@ -207,7 +234,7 @@ bool map::bash(int x, int y, int str, std::string &sound)
   }
   break;
  case t_toilet:
-  if (str >= dice(8, 10)) {
+  if (str >= dice(8, 10) - 8) {
    sound += "porcelain breaking!";
    ter(x, y) = t_rubble;
    return true;
@@ -217,6 +244,7 @@ bool map::bash(int x, int y, int str, std::string &sound)
   }
   break;
  case t_dresser:
+ case t_bookcase:
   if (str >= dice(3, 45)) {
    sound += "smash!";
    ter(x, y) = t_floor;
@@ -231,6 +259,8 @@ bool map::bash(int x, int y, int str, std::string &sound)
   break;
  case t_wall_glass_h:
  case t_wall_glass_v:
+ case t_wall_glass_h_alarm:
+ case t_wall_glass_v_alarm:
   if (str >= rng(0, 20)) {
    sound += "glass breaking!";
    ter(x, y) = t_floor;
@@ -353,13 +383,19 @@ void map::destroy(game *g, int x, int y, bool makesound)
 
 void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
 {
- if (flags & mfb(WF_AMMO_FLAME) && has_flag(flammable, x, y))
+ if (flags & mfb(IF_AMMO_FLAME) && has_flag(flammable, x, y))
   add_field(g, x, y, fd_fire, 2);
 
+ if (has_flag(alarmed, x, y) && !g->event_queued(EVENT_WANTED)) {
+  g->sound(g->u.posx, g->u.posy, 30, "An alarm sounds!");
+  g->add_event(EVENT_WANTED, g->turn + 300, 0, g->levx, g->levy);
+ }
+
  switch (ter(x, y)) {
 
  case t_door_c:
  case t_door_locked:
+ case t_door_locked_alarm:
   dam -= rng(15, 30);
   if (dam > 0)
    ter(x, y) = t_door_b;
@@ -381,6 +417,7 @@ void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
   break;
 
  case t_window:
+ case t_window_alarm:
   dam -= rng(0, 5);
   if (dam > 0)
    ter(x, y) = t_window_frame;
@@ -394,6 +431,8 @@ void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
 
  case t_wall_glass_h:
  case t_wall_glass_v:
+ case t_wall_glass_h_alarm:
+ case t_wall_glass_v_alarm:
   dam -= rng(0, 8);
   if (dam > 0)
    ter(x, y) = t_floor;
@@ -403,14 +442,14 @@ void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
   dam -= rng(4, 16);
   if (dam > 0)
    ter(x, y) = t_dirt;
-  if (flags & mfb(WF_AMMO_INCENDIARY))
+  if (flags & mfb(IF_AMMO_INCENDIARY))
    add_field(g, x, y, fd_fire, 1);
   break;
 
  case t_gas_pump:
   if (hit_items || one_in(3)) {
    if (dam > 15) {
-    if (flags & mfb(WF_AMMO_INCENDIARY) || flags & mfb(WF_AMMO_FLAME))
+    if (flags & mfb(IF_AMMO_INCENDIARY) || flags & mfb(IF_AMMO_FLAME))
      g->explosion(x, y, 40, 0, true);
     else {
      for (int i = x - 2; i <= x + 2; i++) {
@@ -504,13 +543,29 @@ bool map::open_door(int x, int y, bool inside)
  } else if (ter(x, y) == t_door_metal_c) {
   ter(x, y) = t_door_metal_o;
   return true;
- } else if (inside && ter(x, y) == t_door_locked) {
+ } else if (inside &&
+            (ter(x, y) == t_door_locked || ter(x, y) == t_door_locked_alarm)) {
   ter(x, y) = t_door_o;
   return true;
  }
  return false;
 }
 
+void map::translate(ter_id from, ter_id to)
+{
+ if (from == to) {
+  debugmsg("map::translate %s => %s", terlist[from].name.c_str(),
+                                      terlist[from].name.c_str());
+  return;
+ }
+ for (int x = 0; x < SEEX * 3; x++) {
+  for (int y = 0; y < SEEY * 3; y++) {
+   if (ter(x, y) == from)
+    ter(x, y) = to;
+  }
+ }
+}
+
 bool map::close_door(int x, int y)
 {
  if (ter(x, y) == t_door_o) {
@@ -612,12 +667,12 @@ void map::add_item(int x, int y, item new_item)
 {
  if (!inbounds(x, y))
   return;
- if (has_flag(noitem, x, y) || i_at(x, y).size() >= 24) {// Too many items there
+ if (has_flag(noitem, x, y) || i_at(x, y).size() >= 26) {// Too many items there
   std::vector<point> okay;
   for (int i = x - 1; i <= x + 1; i++) {
    for (int j = y - 1; j <= y + 1; j++) {
     if (inbounds(i, j) && move_cost(i, j) > 0 && !has_flag(noitem, i, j) &&
-        i_at(i, j).size() < 24)
+        i_at(i, j).size() < 26)
      okay.push_back(point(i, j));
    }
   }
@@ -625,7 +680,7 @@ void map::add_item(int x, int y, item new_item)
    for (int i = x - 2; i <= x + 2; i++) {
     for (int j = y - 2; j <= y + 2; j++) {
      if (inbounds(i, j) && move_cost(i, j) > 0 && !has_flag(noitem, i, j) &&
-         i_at(i, j).size()<24)
+         i_at(i, j).size() < 26)
       okay.push_back(point(i, j));
     }
    }
@@ -689,12 +744,6 @@ void map::add_trap(int x, int y, trap_id t)
  int nonant;
  cast_to_nonant(x, y, nonant);
  grid[nonant].trp[x][y] = t;
-/*
- debugmsg("trap_id %d; traps.size() %d", t, traps->size());
- if (t == tr_portal)
-  debugmsg("add_trap x:%d y:%d, -> nonant %d %d:%d = %d (%s)", oldx, oldy, 
-           nonant, x, y, t, (*traps)[t]->name.c_str());
-*/
 }
 
 void map::disarm_trap(game *g, int x, int y)
@@ -753,6 +802,17 @@ bool map::add_field(game *g, int x, int y, field_id t, unsigned char density)
  return true;
 }
 
+computer* map::computer_at(int x, int y)
+{
+ if (!inbounds(x, y))
+  return NULL;
+ int nonant;
+ cast_to_nonant(x, y, nonant);
+ if (grid[nonant].comp.name == "")
+  return NULL;
+ return &(grid[nonant].comp);
+}
+
 void map::debug()
 {
  mvprintw(0, 0, "MAP DEBUG");
@@ -1079,7 +1139,7 @@ void map::saven(overmap *om, unsigned int turn, int worldx, int worldy,
  int n = gridx + gridy * 3;
 // Open appropriate file.
  char buff[32];
- sprintf(buff, "save/m.%d.%d.%d", om->posx * OMAPX * 2 + worldx + gridx,
+ sprintf(buff, "/home/user/.cataclysm/tmp/m.%d.%d.%d", om->posx * OMAPX * 2 + worldx + gridx,
                                   om->posy * OMAPY * 2 + worldy + gridy,
                                   om->posz);
  std::ofstream fout;
@@ -1090,7 +1150,7 @@ void map::saven(overmap *om, unsigned int turn, int worldx, int worldy,
 // Dump the terrain. Add 33 to ter to get a human-readable number or symbol.
  for (int j = 0; j < SEEY; j++) {
   for (int i = 0; i < SEEX; i++)
-   fout << char(int(grid[n].ter[i][j]) + 42);
+   fout << char(int(grid[n].ter[i][j]) + 32);
   fout << std::endl;
  }
 // Dump the radiation
@@ -1142,6 +1202,9 @@ void map::saven(overmap *om, unsigned int turn, int worldx, int worldy,
   fout << "S " << int(tmpsp.type) << " " << tmpsp.count << " " << tmpsp.posx <<
           " " << tmpsp.posy << std::endl;
  }
+// Output the computer
+ if (grid[n].comp.name != "")
+  fout << "c " << grid[n].comp.save_data() << std::endl;
 // Close the file; that's all we need.
  fout.close();
 }
@@ -1162,8 +1225,9 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
  item it_tmp;
  std::ifstream mapin;
  std::string databuff;
+ grid[gridn].comp = computer();
 
- sprintf(fname, "save/m.%d.%d.%d", g->cur_om.posx * OMAPX * 2 + worldx + gridx,
+ sprintf(fname, "/home/user/.cataclysm/tmp/m.%d.%d.%d", g->cur_om.posx * OMAPX * 2 + worldx + gridx,
                                    g->cur_om.posy * OMAPY * 2 + worldy + gridy,
                                    g->cur_om.posz);
  mapin.open(fname);
@@ -1177,7 +1241,7 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
   for (int j = 0; j < SEEY; j++) {
    mapin.getline(line, SEEX + 1);
    for (int i = 0; i < SEEX; i++) {
-    grid[gridn].ter[i][j] = ter_id(line[i]-42);
+    grid[gridn].ter[i][j] = ter_id(line[i]-32);
     grid[gridn].itm[i][j].clear();
     grid[gridn].trp[i][j] = tr_null;
     grid[gridn].fld[i][j] = field();
@@ -1221,6 +1285,9 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
     mapin >> t >> a >> itx >> ity;
     spawn_point tmp(mon_id(t), a, itx, ity);
     grid[gridn].spawns.push_back(tmp);
+   } else if (!mapin.eof() && ch == 'c') {
+    getline(mapin, databuff);
+    grid[gridn].comp.load_data(databuff);
    }
   }
   mapin.close();
@@ -1230,8 +1297,7 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
      i = int(turndif / 8) + 1;
    }
   }
- } else {
-// No data on this area.   
+ } else {// No data on this area.  Generate some!
   map tmp_map(itypes, mapitems, traps);
 // overx, overy is where in the overmap we need to pull data from
 // Each overmap square is two nonants; to prevent overlap, generate only at
@@ -1305,14 +1371,4 @@ void cast_to_nonant(int &x, int &y, int &n)
   n = 0;
  else if (n > 8)
   n = 8;
-
- if (x < 0) 
-  x = 0;
- else if (x >= SEEX)
-  x = SEEX - 1;
-
- if (y < 0) 
-  y = 0;
- else if (y >= SEEY) 
-  y = SEEY - 1;
 }
