@@ -643,10 +643,25 @@ void mattack::fear_paralyze(game *g, monster *z)
  }
 }
 
+void mattack::photograph(game *g, monster *z)
+{
+ int t;
+ if (z->faction_id == -1 ||
+     rl_dist(z->posx, z->posy, g->u.posx, g->u.posy) > 6 ||
+     !g->sees_u(z->posx, z->posy, t))
+  return;
+ z->sp_timeout = z->type->sp_freq;
+ z->moves -= 150;
+ g->add_msg("The %s takes your picture!", z->name().c_str());
+// TODO: Make the player known to the faction
+ g->add_event(EVENT_ROBOT_ATTACK, g->turn + rng(15, 30), z->faction_id,
+              g->levx, g->levy);
+}
+
 void mattack::tazer(game *g, monster *z)
 {
  int j;
- if (abs(g->u.posx - z->posx) > 2 || abs(g->u.posy - z->posy) > 2 ||
+ if (rl_dist(z->posx, z->posy, g->u.posx, g->u.posy) > 2 ||
      !g->sees_u(z->posx, z->posy, j))
   return;	// Out of range
  z->sp_timeout = z->type->sp_freq;	// Reset timer
@@ -659,7 +674,46 @@ void mattack::tazer(game *g, monster *z)
 
 void mattack::smg(game *g, monster *z)
 {
- int t, j;
+ int t, j, fire_t;
+ if (z->friendly != 0) { // Attacking monsters, not the player!
+  monster* target = NULL;
+  int closest = 13;
+  for (int i = 0; i < g->z.size(); i++) {
+   int dist = rl_dist(z->posx, z->posy, g->z[i].posx, g->z[i].posy);
+   if (g->z[i].friendly == 0 && dist < closest && 
+       g->m.sees(z->posx, z->posy, g->z[i].posx, g->z[i].posy, 12, t)) {
+    target = &(g->z[i]);
+    closest = dist;
+    fire_t = t;
+   }
+  }
+  if (target == NULL) // Couldn't find any targets!
+   return;
+  z->sp_timeout = z->type->sp_freq;	// Reset timer
+  z->moves = -150;			// It takes a while
+  if (g->u_see(z->posx, z->posy, t))
+   g->add_msg("The %s fires its smg!", z->name().c_str());
+  player tmp;
+  tmp.name = "The " + z->name();
+  tmp.sklevel[sk_smg] = 1;
+  tmp.sklevel[sk_gun] = 0;
+  tmp.recoil = 0;
+  tmp.posx = z->posx;
+  tmp.posy = z->posy;
+  tmp.str_cur = 16;
+  tmp.dex_cur =  6;
+  tmp.per_cur =  8;
+  tmp.weapon = item(g->itypes[itm_smg_9mm], 0);
+  tmp.weapon.curammo = dynamic_cast<it_ammo*>(g->itypes[itm_9mm]);
+  tmp.weapon.charges = 10;
+  std::vector<point> traj = line_to(z->posx, z->posy,
+                                    target->posx, target->posy, fire_t);
+  g->fire(tmp, target->posx, target->posy, traj, true);
+
+  return;
+ }
+ 
+// Not friendly; hence, firing at the player
  if (trig_dist(z->posx, z->posy, g->u.posx, g->u.posy) > 12 ||
      !g->sees_u(z->posx, z->posy, t))
   return;
@@ -668,6 +722,7 @@ void mattack::smg(game *g, monster *z)
 
  if (g->u_see(z->posx, z->posy, j))
   g->add_msg("The %s fires its smg!", z->name().c_str());
+// Set up a temporary player to fire this gun
  player tmp;
  tmp.name = "The " + z->name();
  tmp.sklevel[sk_smg] = 1;
@@ -676,8 +731,8 @@ void mattack::smg(game *g, monster *z)
  tmp.posx = z->posx;
  tmp.posy = z->posy;
  tmp.str_cur = 16;
- tmp.dex_cur =  5;
- tmp.per_cur =  7;
+ tmp.dex_cur =  6;
+ tmp.per_cur =  8;
  tmp.weapon = item(g->itypes[itm_smg_9mm], 0);
  tmp.weapon.curammo = dynamic_cast<it_ammo*>(g->itypes[itm_9mm]);
  tmp.weapon.charges = 10;
@@ -699,6 +754,26 @@ void mattack::flamethrower(game *g, monster *z)
  g->u.add_disease(DI_ONFIRE, 8, g);
 }
 
+void mattack::copbot(game *g, monster *z)
+{
+ int t, mode = 0;
+ bool sees_u = g->sees_u(z->posx, z->posy, t);
+ z->sp_timeout = z->type->sp_freq;	// Reset timer
+ if (rl_dist(z->posx, z->posy, g->u.posx, g->u.posy) > 2 || !sees_u) {
+  if (one_in(3)) {
+   if (sees_u)
+    g->sound(z->posx, z->posy, 18, "a robotic voice boom, \"Citizen, Halt!\"");
+   else
+    g->sound(z->posx, z->posy, 18,
+             "a robotic voice boom, \"Come out with your hands up!\"");
+  } else
+   g->sound(z->posx, z->posy, 18, "a police siren, whoop WHOOP");
+  return;
+ }
+ mattack tmp;
+ tmp.tazer(g, z);
+}
+
 void mattack::multi_robot(game *g, monster *z)
 {
  int t, mode = 0;
