@@ -840,9 +840,9 @@ void npc::pick_name()
  std::ifstream fin;
  char buff[256];
  if (male)
-  fin.open("data/NAMES_MALE");
+  fin.open("/opt/cataclysm/data/NAMES_MALE");
  else
-  fin.open("data/NAMES_FEMALE");
+  fin.open("/opt/cataclysm/data/NAMES_FEMALE");
  if (!fin.is_open()) {
   debugmsg("Could not open npc first names list (%s)",
            (male ? "NAMES_MALE" : "NAMES_FEMALE"));
@@ -855,7 +855,7 @@ void npc::pick_name()
  fin.close();
 
  std::string lastname;
- fin.open("data/NAMES_LAST");
+ fin.open("/opt/cataclysm/data/NAMES_LAST");
  if (!fin.is_open()) {
   debugmsg("Could not open npc last names list (NAMES_LAST)");
   return;
@@ -1168,6 +1168,8 @@ int npc::player_danger(player *u)
 
  if (u->has_disease(DI_DRUNK))
   ret -= 2;
+
+ return ret;
 }
 
 void npc::make_angry()
@@ -1508,7 +1510,7 @@ int npc::danger_assessment(game *g)
 
 bool npc::bravery_check(int diff)
 {
- return (dice(personality.bravery, 15) >= dice(diff, 4));
+ return (dice(10 + personality.bravery, 8) >= dice(diff, 4));
 }
 
 bool npc::emergency(int danger)
